@@ -26,15 +26,4 @@ function (as3d, indexAlpha = 1, points)
     if (length(indexAlpha) == 1) 
         insideVect <- insideVect[[1]]
     return(insideVect)
-}
-intersectiontriangle <-
-function (triangles, coord, points) 
-{
-    points = as.matrix(points, nc = 3)
-    inside <- integer(dim(points)[1])
-    tempdir = as.numeric(2 * runif(3) - 1)
-    retour <- .C("pointinashape", as.integer(triangles), dim(triangles)[1], 
-        as.numeric(coord), dim(coord)[1], as.numeric(points), 
-        dim(points)[1], as.integer(inside), tempdir)
-    return(retour[[7]])
-}
+}
\ No newline at end of file
